@@ -45,6 +45,6 @@ int main()
     if (!runExample(gui))
         return EXIT_FAILURE;
 
-    gui.mainLoop();
+    gui.mainLoop(); // To use your own main loop, see https://tgui.eu/tutorials/latest-stable/backend-sfml-opengl3/#main-loop
     return EXIT_SUCCESS;
 }
