@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,11 +22,9 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_CHILD_WINDOW_HPP
 #define TGUI_CHILD_WINDOW_HPP
 
-
 #include <TGUI/CopiedSharedPtr.hpp>
 #include <TGUI/Container.hpp>
 #include <TGUI/Widgets/Button.hpp>
@@ -52,15 +50,8 @@ TGUI_MODULE_EXPORT namespace tgui
 
         static constexpr const char StaticWidgetType[] = "ChildWindow"; //!< Type name of the widget
 
-
         /// Title alignments, possible options for the setTitleAlignment function
-        enum class TitleAlignment
-        {
-            Left,   //!< Places the title on the left side of the title bar
-            Center, //!< Places the title in the middle of the title bar
-            Right   //!< Places the title on the right side of the title bar
-        };
-
+        using TitleAlignment TGUI_DEPRECATED("Use tgui::HorizontalAlignment instead") = HorizontalAlignment;
 
         /// Title buttons (use bitwise OR to combine)
         enum TitleButton : unsigned int
@@ -80,51 +71,42 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         ChildWindow(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         ChildWindow(const ChildWindow&);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Move constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         ChildWindow(ChildWindow&&) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of copy assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         ChildWindow& operator= (const ChildWindow&);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of move assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         ChildWindow& operator= (ChildWindow&&) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new child window widget
         ///
         /// @return The new child window
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static ChildWindow::Ptr create(const String& title = "", unsigned int titleButtons = TitleButton::Close);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of another child window
         ///
         /// @param childWindow  The other child window
         ///
         /// @return The new child window
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static ChildWindow::Ptr copy(const ChildWindow::ConstPtr& childWindow);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer, which gives access to functions that determine how the widget is displayed
         /// @return Temporary pointer to the renderer that may be shared with other widgets using the same renderer
@@ -139,7 +121,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD ChildWindowRenderer* getRenderer() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the position of the widget
         ///
@@ -150,12 +131,10 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param position New position
         ///
         /// @see move, getPosition
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setPosition(const Layout2d& position) override;
         using Widget::setPosition;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the child window
         ///
@@ -167,7 +146,6 @@ TGUI_MODULE_EXPORT namespace tgui
         void setSize(const Layout2d& size) override;
         using Widget::setSize;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the space available for widgets inside the container
         /// @return Size without borders title bar
@@ -176,7 +154,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getInnerSize() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the client size of the child window
         ///
@@ -186,7 +163,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         virtual void setClientSize(const Layout2d& size);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the client size of the child window
         ///
@@ -196,7 +172,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getClientSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the maximum size of the child window.
         ///
@@ -207,7 +182,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMaximumSize(Vector2f size);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the maximum size of the child window.
         ///
@@ -217,7 +191,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getMaximumSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the minimum size of the child window.
         ///
@@ -228,7 +201,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMinimumSize(Vector2f size);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the minimum size of the child window.
         ///
@@ -238,25 +210,20 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getMinimumSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the title that is displayed in the title bar of the child window
         ///
         /// @param title  New title for the child window
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTitle(const String& title);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the title that is displayed in the title bar of the child window
         ///
         /// @return Title of the child window
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const String& getTitle() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the character size of the title
         /// @param size  The new title text size.
@@ -264,31 +231,25 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTitleTextSize(unsigned int size);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the character size of the title
         /// @return The current title text size
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD unsigned int getTitleTextSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the title alignment
         ///
         /// @param alignment  How should the title be aligned in the title bar?
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void setTitleAlignment(TitleAlignment alignment);
-
+        void setTitleAlignment(HorizontalAlignment alignment);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the title alignment
         ///
         /// @return How the title is aligned in the title bar
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD TitleAlignment getTitleAlignment() const;
-
+        TGUI_NODISCARD HorizontalAlignment getTitleAlignment() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the title buttons
@@ -300,20 +261,16 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @code
         /// childWindow->setTitleButtons(ChildWindow::TitleButton::Minimize | ChildWindow::TitleButton::Close);
         /// @endcode
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTitleButtons(unsigned int buttons);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the title bar buttons
         ///
         /// @return Which buttons are available in the title bar
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD unsigned int getTitleButtons() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Try to close the window
         ///
@@ -324,7 +281,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void close();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Closes the window
         ///
@@ -333,25 +289,20 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void destroy();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes whether the child window can be resized by dragging its borders or not
         ///
         /// @param resizable  Can the user change the size of the window by dragging one of the borders?
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setResizable(bool resizable = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Checks whether the child window can be resized by dragging its borders or not
         ///
         /// @return Can the user change the size of the window by dragging one of the borders?
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isResizable() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes whether the child window can be moved by dragging its title bar or not
         /// @param positionLocked  Is the child window frozen at its current position?
@@ -360,44 +311,48 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setPositionLocked(bool positionLocked = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Checks whether the child window can be moved by dragging its title bar or not
         /// @return Is the child window frozen at its current position?
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isPositionLocked() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the child window to be kept inside its parent
         ///
         /// @param enabled  When it's set to true, the child window will always be kept automatically inside its parent.
         ///                 It's set to false by default.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setKeepInParent(bool enabled = true);
 
-
+#ifndef TGUI_REMOVE_DEPRECATED_CODE
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Tells whether the child window is kept inside its parent
         ///
         /// @return When it's set to true, the child window will always be kept automatically inside its parent.
         ///         It's set to false by default.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD bool isKeptInParent() const;
+        TGUI_DEPRECATED("Use getKeepInParent instead") TGUI_NODISCARD bool isKeptInParent() const;
+#endif
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns whether the child window is kept inside its parent
+        ///
+        /// @return When it's set to true, the child window will always be kept automatically inside its parent.
+        ///         It's set to false by default.
+        ///
+        /// @since TGUI 1.3
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD bool getKeepInParent() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the distance between the position of the container and a widget that would be drawn inside
         ///        this container on relative position (0,0).
         ///
         /// @return Offset of the widgets in the container
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getChildWidgetsOffset() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// This function is called when the widget is added to a container.
@@ -405,12 +360,10 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setParent(Container* parent) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the mouse position (which is relative to the parent widget) lies on top of the widget
         ///
         /// @return Is the mouse on top of the widget?
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isMouseOnWidget(Vector2f pos) const override;
 
@@ -465,17 +418,14 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void leftMouseButtonNoLongerDown() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Draw the widget to a render target
         ///
         /// @param target Render target to draw to
         /// @param states Current render states
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void draw(BackendRenderTarget& target, RenderStates states) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -484,13 +434,11 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateTitleBarHeight();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Updates the mouse cursor for resizable child windows
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateResizeMouseCursor(Vector2f mousePos);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Retrieves a signal based on its name
         ///
@@ -502,46 +450,38 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Signal& getSignal(String signalName) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Function called when one of the properties of the renderer is changed
         ///
         /// @param property  Name of the property that was changed
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void rendererChanged(const String& property) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Saves the widget as a tree node in order to save it to a file
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::unique_ptr<DataIO::Node> save(SavingRenderersMap& renderers) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the widget from a tree of nodes
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void load(const std::unique_ptr<DataIO::Node>& node, const LoadingRenderersMap& renderers) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief This function is called when the mouse enters the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseEnteredWidget() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief This function is called when the mouse leaves the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseLeftWidget() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Makes a copy of the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr clone() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
@@ -550,7 +490,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void connectTitleButtonCallbacks();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     public:
 
@@ -566,7 +505,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @endcode
         SignalTyped<bool*> onClosing = {"Closing"};
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -579,7 +517,6 @@ TGUI_MODULE_EXPORT namespace tgui
             ResizeBottom = 8
         };
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -589,7 +526,7 @@ TGUI_MODULE_EXPORT namespace tgui
         Vector2f       m_minimumSize    = {0, 0};
         Layout*        m_decorationLayoutX = nullptr;
         Layout*        m_decorationLayoutY = nullptr;
-        TitleAlignment m_titleAlignment = TitleAlignment::Center;
+        HorizontalAlignment m_titleAlignment = HorizontalAlignment::Center;
         unsigned int   m_titleButtons   = TitleButton::Close;
         unsigned int   m_titleTextSize  = 0;
         Cursor::Type   m_currentChildWindowMouseCursor = Cursor::Type::Arrow;
