@@ -151,16 +151,22 @@ namespace tgui
         bool pollEvent(Event& event) override
         {
 #if SFML_VERSION_MAJOR >= 3
-            if (const auto eventSFML = m_window.pollEvent())
-                return m_gui->convertEvent(eventSFML, event);
-            else // No new events
-                return false;
+            while (const auto eventSFML = m_window.pollEvent())
+            {
+                if (m_gui->convertEvent(*eventSFML, event))
+                    return true;
+            }
+
+            return false; // No new events
 #else
             sf::Event eventSFML;
-            if (m_window.pollEvent(eventSFML))
-                return m_gui->convertEvent(eventSFML, event);
-            else // No new events
-                return false;
+            while (m_window.pollEvent(eventSFML))
+            {
+                if (m_gui->convertEvent(eventSFML, event))
+                    return true;
+            }
+
+            return false; // No new events
 #endif
         }
 
@@ -290,10 +296,13 @@ namespace tgui
         bool pollEvent(Event& event) override
         {
             SDL_Event eventSDL;
-            if (SDL_PollEvent(&eventSDL) != 0)
-                return m_gui->convertEvent(eventSDL, event);
-            else // No new events
-                return false;
+            while (SDL_PollEvent(&eventSDL) != 0)
+            {
+                if (m_gui->convertEvent(eventSDL, event))
+                    return true;
+            }
+
+            return false; // No new events
         }
 
         void draw() override
@@ -320,8 +329,8 @@ namespace tgui
                 return;
 
 #if SDL_MAJOR_VERSION >= 3
-            SDL_Surface* icon = SDL_CreateSurfaceFrom(pixelPtr.get(), static_cast<int>(iconSize.x), static_cast<int>(iconSize.y),
-                                                      4 * static_cast<int>(iconSize.x), SDL_PIXELFORMAT_RGBA32);
+            SDL_Surface* icon = SDL_CreateSurfaceFrom(static_cast<int>(iconSize.x), static_cast<int>(iconSize.y), SDL_PIXELFORMAT_RGBA32,
+                                                      pixelPtr.get(), 4 * static_cast<int>(iconSize.x));
 #else
             SDL_Surface* icon = SDL_CreateRGBSurfaceWithFormatFrom(pixelPtr.get(), static_cast<int>(iconSize.x), static_cast<int>(iconSize.y),
                                                                    32, 4 * static_cast<int>(iconSize.x), SDL_PIXELFORMAT_RGBA32);
