@@ -178,6 +178,7 @@ namespace tgui
 
         TreeView::Node* findNode(const std::vector<std::shared_ptr<TreeView::Node>>& nodes, const std::vector<String>& hierarchy, unsigned int parentIndex)
         {
+            assert(parentIndex < hierarchy.size());
             for (auto& node : nodes)
             {
                 if (node->text.getString() != hierarchy[parentIndex])
@@ -244,9 +245,6 @@ namespace tgui
     TreeView::TreeView(const char* typeName, bool initRenderer) :
         Widget{typeName, false}
     {
-        // Rotate the horizontal scrollbar
-        m_horizontalScrollbar->setSize(m_horizontalScrollbar->getSize().y, m_horizontalScrollbar->getSize().x);
-
         if (initRenderer)
         {
             m_renderer = aurora::makeCopied<TreeViewRenderer>();
@@ -263,6 +261,7 @@ namespace tgui
 
     TreeView::TreeView(const TreeView& other) :
         Widget                              {other},
+        DualScrollbarChildInterface         {other},
         onItemSelect                        {other.onItemSelect},
         onDoubleClick                       {other.onDoubleClick},
         onExpand                            {other.onExpand},
@@ -273,8 +272,6 @@ namespace tgui
         m_itemHeight                        {other.m_itemHeight},
         m_maxRight                          {other.m_maxRight},
         m_iconBounds                        {other.m_iconBounds},
-        m_verticalScrollbar                 {other.m_verticalScrollbar},
-        m_horizontalScrollbar               {other.m_horizontalScrollbar},
         m_possibleDoubleClick               {other.m_possibleDoubleClick},
         m_doubleClickNodeIndex              {other.m_doubleClickNodeIndex},
         m_spriteBranchExpanded              {other.m_spriteBranchExpanded},
@@ -310,6 +307,7 @@ namespace tgui
         {
             TreeView temp(other);
             Widget::operator=(temp);
+            DualScrollbarChildInterface::operator=(temp);
 
             std::swap(onItemSelect,                         temp.onItemSelect);
             std::swap(onDoubleClick,                        temp.onDoubleClick);
@@ -323,8 +321,6 @@ namespace tgui
             std::swap(m_itemHeight,                         temp.m_itemHeight);
             std::swap(m_maxRight,                           temp.m_maxRight);
             std::swap(m_iconBounds,                         temp.m_iconBounds);
-            std::swap(m_verticalScrollbar,                  temp.m_verticalScrollbar);
-            std::swap(m_horizontalScrollbar,                temp.m_horizontalScrollbar);
             std::swap(m_possibleDoubleClick,                temp.m_possibleDoubleClick);
             std::swap(m_doubleClickNodeIndex,               temp.m_doubleClickNodeIndex);
             std::swap(m_spriteBranchExpanded,               temp.m_spriteBranchExpanded);
@@ -478,6 +474,9 @@ namespace tgui
                 return false;
         }
 
+        if (hierarchy.empty())
+            return false;
+
         auto* node = findNode(m_nodes, hierarchy, 0);
         if (!node)
             return false;
@@ -540,6 +539,141 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    std::vector<String> TreeView::getHoveredItem() const
+    {
+        std::vector<String> hierarchy;
+
+        if (m_hoveredItem < 0)
+            return hierarchy;
+
+        const auto* node = m_visibleNodes[static_cast<std::size_t>(m_hoveredItem)].get();
+        assert(node != nullptr);
+        while (node)
+        {
+            hierarchy.insert(hierarchy.begin(), node->text.getString());
+            node = node->parent;
+        }
+
+        return hierarchy;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    bool TreeView::setItemIndexInParent(const std::vector<String>& hierarchy, std::size_t index)
+    {
+        if (hierarchy.empty())
+            return false;
+
+        std::vector<std::shared_ptr<Node>>* parentNodes;
+        if (hierarchy.size() == 1)
+            parentNodes = &m_nodes;
+        else
+        {
+            std::vector<String> parentHierarchy = hierarchy;
+            parentHierarchy.pop_back();
+            auto* node = findNode(m_nodes, parentHierarchy, 0);
+            if (!node)
+                return false;
+
+            parentNodes = &node->nodes;
+        }
+
+        std::size_t currentIndex = 0;
+        std::shared_ptr<Node> node;
+        for (std::size_t i = 0; i < parentNodes->size(); ++i)
+        {
+            if ((*parentNodes)[i]->text.getString() == hierarchy.back())
+            {
+                node = (*parentNodes)[i];
+                currentIndex = i;
+                break;
+            }
+        }
+
+        if (!node)
+            return false;
+
+        if (currentIndex == index)
+            return true;
+
+        if (index >= parentNodes->size())
+            index = parentNodes->size() - 1;
+
+        parentNodes->erase(parentNodes->begin() + static_cast<std::ptrdiff_t>(currentIndex));
+        parentNodes->insert(parentNodes->begin() + static_cast<std::ptrdiff_t>(index), node);
+        return true;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    int TreeView::getItemIndexInParent(const std::vector<String>& hierarchy)
+    {
+        if (hierarchy.empty())
+            return -1;
+
+        const std::vector<std::shared_ptr<Node>>* parentNodes;
+        if (hierarchy.size() == 1)
+            parentNodes = &m_nodes;
+        else
+        {
+            std::vector<String> parentHierarchy = hierarchy;
+            parentHierarchy.pop_back();
+            auto* node = findNode(m_nodes, parentHierarchy, 0);
+            if (!node)
+                return -1;
+
+            parentNodes = &node->nodes;
+        }
+
+        for (std::size_t i = 0; i < parentNodes->size(); ++i)
+        {
+            if ((*parentNodes)[i]->text.getString() == hierarchy.back())
+                return static_cast<int>(i);
+        }
+
+        return -1;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    bool TreeView::changeItemHierarchy(const std::vector<String>& oldHierarchy, const std::vector<String>& newHierarchy)
+    {
+        if (oldHierarchy.empty() || newHierarchy.empty())
+            return false;
+
+        auto* node = findNode(m_nodes, oldHierarchy, 0);
+        if (!node)
+            return false;
+
+        Node* newParentNode = nullptr;
+        if (newHierarchy.size() > 1)
+        {
+            std::vector<String> parentHierarchy = newHierarchy;
+            parentHierarchy.pop_back();
+            newParentNode = findNode(m_nodes, parentHierarchy, 0);
+            if (!newParentNode)
+                return false;
+        }
+
+        // Remove the node from its old parent
+        auto& oldParentNodes = node->parent ? node->parent->nodes : m_nodes;
+        auto it = std::find_if(oldParentNodes.begin(), oldParentNodes.end(), [node](const std::shared_ptr<Node>& child){ return child.get() == node; });
+        assert(it != oldParentNodes.end());
+        auto nodeSharedPtr = *it;
+        oldParentNodes.erase(it);
+
+        // Add the node to the new parent
+        auto& newParentNodes = newParentNode ? newParentNode->nodes : m_nodes;
+        newParentNodes.push_back(nodeSharedPtr);
+
+        // Update the moved node
+        node->text.setString(newHierarchy.back());
+        node->parent = newParentNode;
+        return true;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void TreeView::toggleNodeInternal(std::size_t index)
     {
         if (index >= m_visibleNodes.size())
@@ -654,6 +788,13 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void TreeView::scrollbarPolicyChanged(Orientation)
+    {
+        markNodesDirty();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void TreeView::setVerticalScrollbarValue(unsigned int value)
     {
         m_verticalScrollbar->setValue(value);
@@ -898,14 +1039,17 @@ namespace tgui
 
     bool TreeView::scrolled(float delta, Vector2f pos, bool touch)
     {
+        const bool horizontalScrollbarCanMove = (m_horizontalScrollbar->getViewportSize() < m_horizontalScrollbar->getMaximum());
+        const bool verticalScrollbarCanMove = (m_verticalScrollbar->getViewportSize() < m_verticalScrollbar->getMaximum());
+
         bool scrollbarMoved = false;
-        if (m_horizontalScrollbar->isShown()
+        if (horizontalScrollbarCanMove
          && !touch
-         && (!m_verticalScrollbar->isShown() || m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()) || keyboard::isShiftPressed()))
+         && (!verticalScrollbarCanMove || m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()) || keyboard::isShiftPressed(m_parentGui)))
         {
             scrollbarMoved = m_horizontalScrollbar->scrolled(delta, pos - getPosition(), touch);
         }
-        else if (m_verticalScrollbar->isShown())
+        else if (verticalScrollbarCanMove)
         {
             scrollbarMoved = m_verticalScrollbar->scrolled(delta, pos - getPosition(), touch);
         }
@@ -1138,16 +1282,16 @@ namespace tgui
             if (getSharedRenderer()->getScrollbarWidth() == 0)
             {
                 const float width = m_verticalScrollbar->getDefaultWidth();
-                m_verticalScrollbar->setSize({width, m_verticalScrollbar->getSize().y});
-                m_horizontalScrollbar->setSize({m_horizontalScrollbar->getSize().x, width});
+                m_verticalScrollbar->setWidth(width);
+                m_horizontalScrollbar->setHeight(width);
                 markNodesDirty();
             }
         }
         else if (property == U"ScrollbarWidth")
         {
             const float width = (getSharedRenderer()->getScrollbarWidth() != 0) ? getSharedRenderer()->getScrollbarWidth() : m_verticalScrollbar->getDefaultWidth();
-            m_verticalScrollbar->setSize({width, m_verticalScrollbar->getSize().y});
-            m_horizontalScrollbar->setSize({m_horizontalScrollbar->getSize().x, width});
+            m_verticalScrollbar->setWidth(width);
+            m_horizontalScrollbar->setHeight(width);
             markNodesDirty();
         }
         else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
@@ -1180,6 +1324,7 @@ namespace tgui
         auto node = Widget::save(renderers);
         node->propertyValuePairs[U"ItemHeight"] = std::make_unique<DataIO::ValueNode>(String::fromNumber(m_itemHeight));
         saveItems(node, m_nodes);
+        saveScrollbarPolicies(node);
         return node;
     }
 
@@ -1193,6 +1338,7 @@ namespace tgui
             setItemHeight(node->propertyValuePairs[U"ItemHeight"]->value.toUInt());
 
         loadItems(node, m_nodes, nullptr);
+        loadScrollbarPolicies(node);
 
         // Remove the 'Item' nodes as they have been processed
         node->children.erase(std::remove_if(node->children.begin(), node->children.end(),
@@ -1306,7 +1452,10 @@ namespace tgui
         m_verticalScrollbar->setMaximum(static_cast<unsigned int>(m_itemHeight * m_visibleNodes.size()));
         m_horizontalScrollbar->setMaximum(static_cast<unsigned int>(m_maxRight));
 
-        if ((m_maxRight + m_verticalScrollbar->getSize().x) > (getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()))
+        const bool horizontalScrollbarShown = (m_horizontalScrollbar->getPolicy() == Scrollbar::Policy::Always)
+            || (((m_maxRight + m_verticalScrollbar->getSize().x) > (getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()))
+             && (m_horizontalScrollbar->getPolicy() != Scrollbar::Policy::Never));
+        if (horizontalScrollbarShown)
         {
             m_verticalScrollbar->setSize({m_verticalScrollbar->getSize().x, std::max(0.f, getInnerSize().y - m_horizontalScrollbar->getSize().y)});
             m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_horizontalScrollbar->getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
