@@ -22,6 +22,11 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+#include <TGUI/Config.hpp>
+#if TGUI_HAS_WINDOW_BACKEND_SFML
+    #include <SFML/System/Time.hpp>
+#endif
+
 #include "Tests.hpp"
 
 TEST_CASE("[Duration]")
