@@ -350,6 +350,19 @@ TEST_CASE("[ListBox]")
         REQUIRE(listBox->getScrollbarMaxValue() == 17);
     }
 
+    SECTION("Scrollbar access")
+    {
+        listBox->setSize(200, 100);
+        listBox->setItemHeight(20);
+        listBox->addItem("1");
+        listBox->addItem("2");
+        listBox->addItem("3");
+        listBox->addItem("4");
+        listBox->addItem("5");
+        listBox->addItem("6");
+        testScrollbarAccess(listBox->getScrollbar());
+    }
+
     testWidgetSignals(listBox);
     SECTION("Events / Signals")
     {
@@ -400,6 +413,7 @@ TEST_CASE("[ListBox]")
         {
             // Clicking the border does nothing
             mouseMoved({11, 21});
+            REQUIRE(listBox->getHoveredItemIndex() == -1);
             mousePressed({11, 21});
             mouseReleased({11, 21});
             REQUIRE(itemSelectedCount == 0);
@@ -407,6 +421,7 @@ TEST_CASE("[ListBox]")
 
             // Select the first item
             mouseMoved({12, 22});
+            REQUIRE(listBox->getHoveredItemIndex() == 0);
             mousePressed({12, 22});
             mouseReleased({12, 22});
             REQUIRE(itemSelectedCount == 1);
