@@ -244,6 +244,16 @@ TEST_CASE("[PanelListBox]")
         REQUIRE(panelListBox->getItemByIndex(2) == panel3);
     }
 
+    SECTION("Scrollbar access")
+    {
+        panelListBox->setSize(200, 100);
+        panelListBox->setItemsHeight(25);
+        for (unsigned int i = 0; i < 6; ++i)
+            panelListBox->addItem();
+        testScrollbarAccess(panelListBox->getVerticalScrollbar());
+        REQUIRE(panelListBox->getHorizontalScrollbar()->getPolicy() == tgui::Scrollbar::Policy::Never);
+    }
+
     testWidgetSignals(panelListBox);
     SECTION("Events / Signals")
     {
@@ -279,6 +289,7 @@ TEST_CASE("[PanelListBox]")
         {
             // Clicking the border does nothing
             mouseMoved({11, 21});
+            REQUIRE(panelListBox->getHoveredItemIndex() == -1);
             mousePressed({11, 21});
             mouseReleased({11, 21});
             REQUIRE(itemSelectedCount == 0);
@@ -286,6 +297,7 @@ TEST_CASE("[PanelListBox]")
 
             // Select the first item
             mouseMoved({12, 22});
+            REQUIRE(panelListBox->getHoveredItemIndex() == 0);
             mousePressed({12, 22});
             mouseReleased({12, 22});
             REQUIRE(itemSelectedCount == 1);
