@@ -267,6 +267,11 @@ TEST_CASE("[TreeView]")
 
         treeView->deselectItem();
         REQUIRE(treeView->getSelectedItem().empty());
+
+        REQUIRE(!treeView->selectItem({"Smilies", "NonExistent"}));
+        REQUIRE(!treeView->selectItem({"NonExistent"}));
+        REQUIRE(!treeView->selectItem({}));
+        REQUIRE(treeView->getSelectedItem().empty());
     }
 
     SECTION("ItemHeight")
@@ -310,6 +315,154 @@ TEST_CASE("[TreeView]")
         REQUIRE(treeView->getHorizontalScrollbarValue() == 15);
     }
 
+    SECTION("Scrollbar access")
+    {
+        treeView->setSize(70, 70);
+        treeView->setItemHeight(20);
+        treeView->addItem({"Smilies", "Happy"});
+        treeView->addItem({"Smilies", "Sad"});
+        treeView->addItem({"Smilies", "Neither"});
+        testScrollbarAccess(treeView->getVerticalScrollbar());
+        testScrollbarAccess(treeView->getHorizontalScrollbar());
+    }
+
+    SECTION("ItemIndexInParent")
+    {
+        treeView->addItem({"Smilies", "Happy"});
+        treeView->addItem({"Smilies", "Sad"});
+        treeView->addItem({"Smilies", "Neither"});
+        treeView->addItem({"Vehicles", "Parts", "Wheel"});
+        treeView->addItem({"Vehicles", "Whole", "Truck"});
+        treeView->addItem({"Vehicles", "Whole", "Car"});
+        treeView->addItem({"Vehicles", "Whole", "Train"});
+        treeView->collapseAll();
+
+        REQUIRE(treeView->getItemIndexInParent({"Smilies"}) == 0);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles"}) == 1);
+
+        REQUIRE(treeView->getItemIndexInParent({"Smilies", "Happy"}) == 0);
+        REQUIRE(treeView->getItemIndexInParent({"Smilies", "Sad"}) == 1);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Parts"}) == 0);
+
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Parts", "Wheel"}) == 0);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Whole", "Truck"}) == 0);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Whole", "Train"}) == 2);
+
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Parts", "Wheel", "NonExistent"}) == -1);
+        REQUIRE(treeView->getItemIndexInParent({"NonExistent", "Happy"}) == -1);
+        REQUIRE(treeView->getItemIndexInParent({"NonExistent"}) == -1);
+        REQUIRE(treeView->getItemIndexInParent({}) == -1);
+
+        REQUIRE(!treeView->setItemIndexInParent({}, 0));
+        REQUIRE(!treeView->setItemIndexInParent({"NonExistent"}, 0));
+        REQUIRE(!treeView->setItemIndexInParent({"NonExistent", "Happy"}, 0));
+        REQUIRE(!treeView->setItemIndexInParent({"Vehicles", "Parts", "Wheel", "NonExistent"}, 0));
+
+        REQUIRE(treeView->getNodes()[0].text == "Smilies");
+        REQUIRE(treeView->getNodes()[1].text == "Vehicles");
+        REQUIRE(treeView->getNodes()[0].nodes[1].text == "Sad");
+        REQUIRE(treeView->getNodes()[1].nodes[1].text == "Whole");
+
+        REQUIRE(treeView->setItemIndexInParent({"Smilies"}, 1));
+        REQUIRE(treeView->getNodes()[0].text == "Vehicles");
+        REQUIRE(treeView->getNodes()[1].text == "Smilies");
+        REQUIRE(treeView->getNodes()[1].nodes[1].text == "Sad");
+
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Truck");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Car");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Train");
+
+        REQUIRE(treeView->setItemIndexInParent({"Vehicles", "Whole", "Car"}, 0));
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Truck");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Train");
+
+        REQUIRE(treeView->setItemIndexInParent({"Vehicles", "Whole", "Truck"}, 2));
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Train");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Truck");
+
+        REQUIRE(treeView->setItemIndexInParent({"Vehicles", "Whole", "Train"}, 1));
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Train");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Truck");
+
+        REQUIRE(treeView->setItemIndexInParent({"Vehicles", "Whole", "Truck"}, 25));
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Train");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Truck");
+
+        REQUIRE(treeView->setItemIndexInParent({"Vehicles", "Whole", "Car"}, 25));
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[0].text == "Train");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[1].text == "Truck");
+        REQUIRE(treeView->getNodes()[0].nodes[1].nodes[2].text == "Car");
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Whole", "Train"}) == 0);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Whole", "Truck"}) == 1);
+        REQUIRE(treeView->getItemIndexInParent({"Vehicles", "Whole", "Car"}) == 2);
+    }
+
+    SECTION("changeItemHierarchy")
+    {
+        treeView->addItem({"Smilies", "Happy"});
+        treeView->addItem({"Smilies", "Sad"});
+        treeView->addItem({"Smilies", "Neither"});
+        treeView->addItem({"Vehicles", "Parts", "Wheel"});
+        treeView->addItem({"Vehicles", "Whole", "Truck"});
+        treeView->addItem({"Vehicles", "Whole", "Car"});
+        treeView->addItem({"Vehicles", "Whole", "Train"});
+
+        REQUIRE(!treeView->changeItemHierarchy({"Smilies", "Sad"}, {}));
+        REQUIRE(!treeView->changeItemHierarchy({"Smilies", "Sad"}, {"NonExistent", "New"}));
+        REQUIRE(!treeView->changeItemHierarchy({"Smilies", "Sad"}, {"Vehicles", "NonExistent", "New"}));
+        REQUIRE(!treeView->changeItemHierarchy({"Smilies", "NonExistent"}, {"New"}));
+        REQUIRE(!treeView->changeItemHierarchy({"NonExistent"}, {"New"}));
+        REQUIRE(!treeView->changeItemHierarchy({}, {"New"}));
+
+        treeView->changeItemHierarchy({"Vehicles", "Whole", "Train"}, {"Vehicles", "Whole", "Train"});
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[0].text == "Truck");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[1].text == "Car");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[2].text == "Train");
+
+        treeView->changeItemHierarchy({"Vehicles", "Whole", "Truck"}, {"Vehicles", "Whole", "Truck"});
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[1].text == "Train");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[2].text == "Truck");
+
+        treeView->changeItemHierarchy({"Vehicles", "Whole", "Train"}, {"Vehicles", "Whole", "Bike"});
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[0].text == "Car");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[1].text == "Truck");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[2].text == "Bike");
+
+        treeView->changeItemHierarchy({"Vehicles", "Whole", "Car"}, {"Smilies", "MovedCar"});
+        REQUIRE(treeView->getNodes()[0].nodes[2].text == "Neither");
+        REQUIRE(treeView->getNodes()[0].nodes[3].text == "MovedCar");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[0].text == "Truck");
+        REQUIRE(treeView->getNodes()[1].nodes[1].nodes[1].text == "Bike");
+
+        treeView->changeItemHierarchy({"Vehicles", "Whole"}, {"MovedWhole"});
+        REQUIRE(treeView->getNodes()[1].text == "Vehicles");
+        REQUIRE(treeView->getNodes()[2].text == "MovedWhole");
+        REQUIRE(treeView->getNodes()[2].nodes[0].text == "Truck");
+        REQUIRE(treeView->getNodes()[2].nodes[1].text == "Bike");
+        REQUIRE(treeView->getNodes()[1].nodes[0].text == "Parts");
+        REQUIRE(treeView->getNodes()[1].nodes.size() == 1);
+
+        treeView->changeItemHierarchy({"Smilies"}, {"Vehicles", "Parts", "MovedSmilies"});
+        REQUIRE(treeView->getNodes().size() == 2);
+        REQUIRE(treeView->getNodes()[0].text == "Vehicles");
+        REQUIRE(treeView->getNodes()[1].text == "MovedWhole");
+        REQUIRE(treeView->getNodes()[0].nodes.size() == 1);
+        REQUIRE(treeView->getNodes()[0].nodes[0].text == "Parts");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes.size() == 2);
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[0].text == "Wheel");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].text == "MovedSmilies");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].nodes.size() == 4);
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].nodes[0].text == "Happy");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].nodes[1].text == "Sad");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].nodes[2].text == "Neither");
+        REQUIRE(treeView->getNodes()[0].nodes[0].nodes[1].nodes[3].text == "MovedCar");
+    }
+
     testWidgetSignals(treeView);
     SECTION("Events / Signals")
     {
@@ -354,6 +507,7 @@ TEST_CASE("[TreeView]")
         {
             // Clicking the border does nothing
             mouseMoved({11, 21});
+            REQUIRE(treeView->getHoveredItem().empty());
             mousePressed({11, 21});
             mouseReleased({11, 21});
             REQUIRE(itemSelectedCount == 0);
@@ -361,6 +515,7 @@ TEST_CASE("[TreeView]")
 
             // Select the first row
             mouseMoved({12, 22});
+            REQUIRE(treeView->getHoveredItem() == std::vector<tgui::String>{"Smilies"});
             mousePressed({12, 22});
             mouseReleased({12, 22});
             REQUIRE(itemSelectedCount == 1);
